import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, ViewChild, Input, Output, HostBinding, HostListener, NgModule } from '@angular/core';
import { map, filter, debounceTime, distinctUntilChanged, switchMap, shareReplay, startWith } from 'rxjs/operators';
import { wktToGeoJSON } from '@terraformer/wkt';
import * as i1 from '@angular/common/http';
import { HttpClientModule } from '@angular/common/http';
import { __awaiter } from 'tslib';
import * as i3 from '@angular/forms';
import { FormControl, ReactiveFormsModule } from '@angular/forms';
import { tap, BehaviorSubject, merge, combineLatest } from 'rxjs';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';

class GeocoderService {
    constructor(http) {
        this.http = http;
        this.geocoderBaseUrl = 'https://geodata.nationaalgeoregister.nl/locatieserver/v3';
    }
    suggest$(query, options) {
        let params = {
            q: query,
            fq: '*',
            start: 0,
        };
        if (options) {
            params = Object.assign(params, options);
        }
        return this.http.get(`${this.geocoderBaseUrl}/suggest?`, { params: params })
            .pipe(map((suggestResultObject) => {
            const collations = this.formatCollations(suggestResultObject.spellcheck.collations);
            const places = this.formatPlaces(suggestResultObject);
            return { collations, places };
        }));
    }
    lookup$(id, options) {
        let params = {
            id: id,
            fl: '*'
        };
        if (options) {
            params = Object.assign(params, options);
        }
        return this.http.get(`${this.geocoderBaseUrl}/lookup?`, { params: params }).pipe(map((lookupResponse) => this.formatLookupResponse(lookupResponse)));
    }
    free$(searchTerm, options) {
        let params = {
            q: searchTerm,
            fl: '*',
            fq: '*',
            rows: 10,
            start: 0,
        };
        if (options) {
            params = Object.assign(params, options);
        }
        return this.http.get(`${this.geocoderBaseUrl}/free?`, { params: params }).pipe(map((freeResponse) => this.formatReverseResponse(freeResponse)));
    }
    reverse$(location, options) {
        let params = {
            type: 'adres',
            fq: '*',
            fl: '*',
            rows: 10,
            distance: 200 // meter,
        };
        if (options) {
            params = Object.assign(params, options, location);
        }
        const reverseUrl = 'https://geodata.nationaalgeoregister.nl/locatieserver/revgeo?';
        return this.http.get(reverseUrl, { params: params }).pipe(map((reverseResponse) => this.formatReverseResponse(reverseResponse)));
    }
    formatCollations(collations) {
        const parsedCollations = [];
        for (let i = 0; i < collations.length; i += 2) {
            const collation = {
                id: i,
                naam: collations[i + 1].misspellingsAndCorrections[1],
                weergavenaam: `${collations[i + 1].hits} resultaten voor <strong> "${collations[i + 1].misspellingsAndCorrections[1]}"</strong>`,
                hits: collations[i + 1].hits,
            };
            parsedCollations.push(collation);
        }
        return parsedCollations;
    }
    formatPlaces(suggestResponse) {
        const places = suggestResponse.response.docs.map((place) => {
            return Object.assign(Object.assign({}, place), { highlight: suggestResponse.highlighting[place.id].suggest[0] });
        });
        return places;
    }
    /**
     * Parse WKT in lookup response.
     */
    formatLookupResponse(lookupResponse) {
        const formatted = lookupResponse.response.docs.map((lookupResult) => {
            const formattedLookupResult = lookupResult;
            if (lookupResult.centroide_ll) {
                formattedLookupResult.centroide_ll = wktToGeoJSON(lookupResult.centroide_ll);
            }
            if (lookupResult.centroide_rd) {
                formattedLookupResult.centroide_rd = wktToGeoJSON(lookupResult.centroide_rd);
            }
            if (lookupResult.geometrie_rd) {
                formattedLookupResult.geometrie_rd = wktToGeoJSON(lookupResult.geometrie_rd);
            }
            if (lookupResult.geometrie_ll) {
                formattedLookupResult.geometrie_ll = wktToGeoJSON(lookupResult.geometrie_ll);
            }
            return formattedLookupResult;
        });
        return formatted[0] || {};
    }
    formatReverseResponse(lookupResultObject) {
        const formatted = lookupResultObject.response.docs.map((reverseResult) => {
            const formattedLookupResult = reverseResult;
            if (reverseResult.centroide_ll) {
                formattedLookupResult.centroide_ll = wktToGeoJSON(reverseResult.centroide_ll);
            }
            if (reverseResult.centroide_rd) {
                formattedLookupResult.centroide_rd = wktToGeoJSON(reverseResult.centroide_rd);
            }
            if (reverseResult.geometrie_rd) {
                formattedLookupResult.geometrie_rd = wktToGeoJSON(reverseResult.geometrie_rd);
            }
            if (reverseResult.geometrie_ll) {
                formattedLookupResult.geometrie_ll = wktToGeoJSON(reverseResult.geometrie_ll);
            }
            formattedLookupResult.highlight = reverseResult.weergavenaam;
            return formattedLookupResult;
        });
        return formatted;
    }
}
GeocoderService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.6", ngImport: i0, type: GeocoderService, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
GeocoderService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.0.6", ngImport: i0, type: GeocoderService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.6", ngImport: i0, type: GeocoderService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.HttpClient }]; } });

class GeocoderComponent {
    constructor(geocoderService) {
        this.geocoderService = geocoderService;
        this.resultCountLimit = 12;
        this.fullscreen = false;
        this.placeFound = new EventEmitter();
        this.clearResults = new EventEmitter();
        this.query = new EventEmitter();
        this.hasFocus = false;
        this.formattedPlaceholder = '';
        this.searchControl = new FormControl(undefined);
        this.suggest$ = this.searchControl.valueChanges.pipe(filter(searchInput => searchInput.length > this.searchThreshold), debounceTime(200), distinctUntilChanged(), tap((input) => this.query.emit(input)), switchMap(searchInput => this.suggest(searchInput)), shareReplay());
        this.otherResults$ = new BehaviorSubject([]);
        this.collationclear$ = new BehaviorSubject([]);
        this.places$ = merge(this.suggest$.pipe(map((response) => response.places)), this.otherResults$);
        this.collations$ = merge(this.suggest$.pipe(map(response => response.collations)), this.collationclear$);
        this.foundPlace$ = new BehaviorSubject(null);
        this.searchThreshold = 2;
        this.selectedIndex = -1;
        this.lookupResponseFound = false;
        this.reachedThreshold$ = this.searchControl.valueChanges.pipe(startWith(''), map(val => (val && val.length) > this.searchThreshold));
        this.noPlacesFound$ = this.places$.pipe(map(places => places.length === 0));
        this.noResult$ = this.foundPlace$.pipe(map(place => place === null));
        this.isNoResultsFound$ = combineLatest([this.reachedThreshold$, this.noPlacesFound$, this.noResult$]).pipe(map(([reachedThreshold, noSuggestions, noResult]) => reachedThreshold && noSuggestions && noResult));
    }
    clickout(event) {
        if (this.geocoderRef.nativeElement.contains(event.target)) {
            this.showSuggestions();
        }
        else {
            this.hideResults();
        }
    }
    ngOnInit() {
        this.formattedPlaceholder = this.formatPlaceholder(this.placeholder);
    }
    ngOnChanges(changes) {
        if (changes.searchInput) {
            this.searchControl.setValue(changes.searchInput.currentValue);
        }
    }
    suggest(searchTerm) {
        const flArray = ['id', 'score', 'type', 'weergavenaam', 'straatnaam', 'huis_nlt', 'woonplaatsnaam', 'kadastrale_gemeentecode', 'kadastrale_sectie', 'perceelnummer', 'kadastrale_gemeentenaam'];
        const params = {
            fq: '*:*',
            fl: flArray.toString(),
            rows: this.resultCountLimit
        };
        const formattedSearchTerm = this.formatSearchTerm(searchTerm);
        if (this.type) {
            const replace = ',';
            const regex = new RegExp(replace, 'g');
            const query = this.type.replace(regex, ' OR ');
            params.fq = `type:(${query})`;
            if (this.province) {
                params.fq += ` AND provincienaam:(${this.province})`;
            }
        }
        else if (this.province) {
            params.fq = `provincienaam:(${this.province})`;
        }
        return this.geocoderService.suggest$(formattedSearchTerm, params);
    }
    lookup(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const lookupObj = yield this.geocoderService.lookup$(id).toPromise();
            this.foundPlace$.next(lookupObj);
            this.fillInput(lookupObj.weergavenaam);
            this.placeFound.emit(lookupObj);
            this.lookupResponseFound = true;
            this.clearPlaces();
            this.hideResults();
        });
    }
    clear() {
        this.foundPlace$.next(null);
        this.searchControl.setValue('');
        this.clearPlaces();
        this.lookupResponseFound = false;
        this.hideResults();
        this.clearResults.emit(true);
    }
    clearPlaces() {
        this.resetIndex();
        this.otherResults$.next([]);
        this.collationclear$.next([]);
    }
    handleEnter(places) {
        if (this.selectedIndex === -1) {
            return;
        }
        const selectedPlace = places[this.selectedIndex];
        this.lookup(selectedPlace.id);
    }
    fillInput(content, emitEvent = false) {
        this.searchControl.setValue(content, {
            emitEvent: emitEvent
        });
    }
    isHighlighted(i) {
        if (i === this.selectedIndex) {
            return true;
        }
    }
    moveUp() {
        if (this.selectedIndex > 0) {
            this.selectedIndex--;
        }
    }
    moveDown(places) {
        if (this.selectedIndex < places.length) {
            this.selectedIndex++;
        }
    }
    resetIndex() {
        this.selectedIndex = -1;
    }
    canQuery() {
        const searchInput = this.searchControl.value;
        return searchInput && searchInput.length > this.searchThreshold;
    }
    canClear() {
        const searchInput = this.searchControl.value;
        return searchInput && searchInput.length > 0;
    }
    formatPlaceholder(placeholder) {
        let placeholderText = 'Zoeken op de kaart...';
        if (placeholder) {
            placeholderText = placeholder;
        }
        return placeholderText;
    }
    onCollationClick(name) {
        this.fillInput(name, true);
    }
    showSuggestions() {
        this.hasFocus = true;
    }
    hideResults() {
        this.hasFocus = false;
    }
    formatSearchTerm(searchTerm) {
        const isKadastraleAanduidingRegex = /[a-zA-Z]{3}[0-9]{2}[a-zA-Z]{1,2}[0-9]{1,5}/;
        if (isKadastraleAanduidingRegex.test(searchTerm) === true) {
            // Use three capturing groups () () () to split the string by.
            const splitAanduidingRegex = /([a-zA-Z]{3}[0-9]{2})([a-zA-Z]{1,2})([0-9]{1,5})/;
            const formattedTerm = searchTerm.split(splitAanduidingRegex).filter(str => str !== '').join(' ');
            return formattedTerm;
        }
        return searchTerm;
    }
}
GeocoderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.6", ngImport: i0, type: GeocoderComponent, deps: [{ token: GeocoderService }], target: i0.ɵɵFactoryTarget.Component });
GeocoderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.0.6", type: GeocoderComponent, selector: "angular-geocoder", inputs: { type: "type", searchInput: "searchInput", placeholder: "placeholder", resultCountLimit: "resultCountLimit", province: "province", fullscreen: "fullscreen" }, outputs: { placeFound: "placeFound", clearResults: "clearResults", query: "query" }, host: { listeners: { "document:click": "clickout($event)" }, properties: { "class.geocoder--selected": "this.hasFocus" }, classAttribute: "geocoder" }, viewQueries: [{ propertyName: "geocoderRef", first: true, predicate: ["geocoder"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div *ngIf=\"places$ | async as places\" #geocoder (keydown.ArrowUp)=\"moveUp()\" (keydown.ArrowDown)=\"moveDown(places)\"\r\n  (keydown.Enter)=\"handleEnter(places)\" class=\"geocoder-container\"\r\n  [class.geocoder-fullscreen-mode]=\"hasFocus && fullscreen\">\r\n  <!-- Input -->\r\n  <div class=\"geocoder-search-container\">\r\n    <button class=\"backButton\" *ngIf=\"hasFocus === true && fullscreen === true\" (click)=\"clear()\">\r\n      <svg height=\"24px\" version=\"1.1\" viewBox=\"0 0 768 768\">\r\n        <g id=\"ignore\">\r\n        </g>\r\n        <path\r\n          d=\"M406.624 585.376l-169.376-169.376h370.752c17.664 0 32-14.336 32-32s-14.336-32-32-32h-370.752l169.376-169.376c12.512-12.512 12.512-32.768 0-45.248s-32.768-12.512-45.248 0l-224 224c-3.072 3.072-5.376 6.592-6.944 10.368-1.632 3.904-2.432 8.096-2.432 12.256 0 8.192 3.136 16.384 9.376 22.624l224 224c12.512 12.512 32.768 12.512 45.248 0s12.512-32.768 0-45.248z\">\r\n        </path>\r\n      </svg>\r\n    </button>\r\n    <input (focus)=\"showSuggestions()\" [formControl]=\"searchControl\" class=\"geocoder-search-input\"\r\n      [placeholder]=\"formattedPlaceholder\" type=\"text\" maxlength=\"100\">\r\n    <button class=\"searchButton\" [class.searchButton--resultshown]=\"lookupResponseFound === true\" [ngClass]=\"{'highlight': canQuery()}\">\r\n      <svg viewBox=\"0 0 512 512\">\r\n        <path fill=\"currentColor\"\r\n          d=\"M508.5 481.6l-129-129c-2.3-2.3-5.3-3.5-8.5-3.5h-10.3C395 312 416 262.5 416 208 416 93.1 322.9 0 208 0S0 93.1 0 208s93.1 208 208 208c54.5 0 104-21 141.1-55.2V371c0 3.2 1.3 6.2 3.5 8.5l129 129c4.7 4.7 12.3 4.7 17 0l9.9-9.9c4.7-4.7 4.7-12.3 0-17zM208 384c-97.3 0-176-78.7-176-176S110.7 32 208 32s176 78.7 176 176-78.7 176-176 176z\"\r\n          class=\"\"></path>\r\n      </svg>\r\n    </button>\r\n    <button *ngIf=\"lookupResponseFound === true\" class=\"closeButton\" (click)=\"clear()\"\r\n      [ngClass]=\"{'highlight': canClear()}\"> \r\n      <svg viewBox=\"0 0 384 512\">\r\n        <path fill=\"currentColor\"\r\n          d=\"M217.5 256l137.2-137.2c4.7-4.7 4.7-12.3 0-17l-8.5-8.5c-4.7-4.7-12.3-4.7-17 0L192 230.5 54.8 93.4c-4.7-4.7-12.3-4.7-17 0l-8.5 8.5c-4.7 4.7-4.7 12.3 0 17L166.5 256 29.4 393.2c-4.7 4.7-4.7 12.3 0 17l8.5 8.5c4.7 4.7 12.3 4.7 17 0L192 281.5l137.2 137.2c4.7 4.7 12.3 4.7 17 0l8.5-8.5c4.7-4.7 4.7-12.3 0-17L217.5 256z\"\r\n          class=\"\"></path>\r\n      </svg>\r\n    </button>\r\n  </div>\r\n\r\n  <ng-container *ngIf=\"hasFocus === true\">\r\n    <!-- Search results-->\r\n    <div class=\"geocoder-suggestions-results\" *ngIf=\"places.length > 0\">\r\n      <ul class=\"geocoder-suggestions-list\">\r\n        <li class=\"geocoder-suggestion\" tabindex={{i}} *ngFor=\"let place of places; let i = index;\"\r\n          (click)=\"lookup(place.id)\" [ngClass]=\"{'focus-background': isHighlighted(i)}\">\r\n\r\n          <ng-container [ngSwitch]=\"place.type\">\r\n\r\n            <!-- Adres -->\r\n            <ng-container *ngSwitchCase=\"'adres'\">\r\n              <div class=\"geocoder-suggestion-main\">\r\n                <div class=\"geocoder-suggestion-title\">\r\n                  {{place.straatnaam }} {{place.huis_nlt}}\r\n                </div>\r\n                <div class=\"geocoder-suggestion-subtitle\"> {{place.woonplaatsnaam}}</div>\r\n              </div>\r\n            </ng-container>\r\n\r\n            <!-- Perceel -->\r\n            <ng-container *ngSwitchCase=\"'perceel'\">\r\n              <div class=\"geocoder-suggestion-main\">\r\n                <div class=\"geocoder-suggestion-title\">\r\n                  Perceel {{place.kadastrale_gemeentecode }} {{place.kadastrale_sectie}} {{place.perceelnummer}}\r\n                </div>\r\n                <div class=\"geocoder-suggestion-subtitle\"> {{place.kadastrale_gemeentenaam}}</div>\r\n              </div>\r\n            </ng-container>\r\n\r\n            <!-- Weg -->\r\n            <ng-container *ngSwitchCase=\"'weg'\">\r\n              <div class=\"geocoder-suggestion-main\">\r\n                <div class=\"geocoder-suggestion-title\">\r\n                  {{place.straatnaam }}\r\n                </div>\r\n                <div class=\"geocoder-suggestion-subtitle\"> {{place.woonplaatsnaam}}</div>\r\n              </div>\r\n            </ng-container>\r\n\r\n            <!-- Anything other than addres, parcel en weg -->\r\n            <ng-container *ngSwitchDefault>\r\n              <div class=\"geocoder-suggestion-main\">\r\n                <p class=\"geocoder-suggestion-title\"\r\n                  [innerHTML]=\"place.highlight\">\r\n                </p>\r\n              </div>\r\n            </ng-container>\r\n\r\n          </ng-container>\r\n\r\n          <p class=\"geocoder-suggestion-type\"> {{place.type}} </p>\r\n\r\n        </li>\r\n      </ul>\r\n    </div>\r\n\r\n    <div class=\"geocoder-no-results\" *ngIf=\"(isNoResultsFound$ | async) === true\">\r\n      <p>Geen zoekresultaten voor <strong>\"{{searchControl.value}}\"</strong></p>\r\n    </div>\r\n\r\n    <ng-container *ngIf=\"collations$ | async as collations\">\r\n      <ng-container *ngIf=\"noResult$ | async as noResult\">\r\n        <div class=\"geocoder-collations\" *ngIf=\"collations.length > 0 && places.length === 0 && noResult\">\r\n          <ul class=\"geocoder-collations-list\">\r\n            <li class=\"geocoder-collation\" tabindex={{i}} (click)=\"onCollationClick(collation.naam)\"\r\n              *ngFor=\"let collation of collations; let i = index;\" [innerHTML]=\"collation.weergavenaam\">\r\n            </li>\r\n          </ul>\r\n        </div>\r\n      </ng-container>\r\n    </ng-container>\r\n\r\n    <!-- Backdrop-->\r\n    <div *ngIf=\"fullscreen === true\" class=\"geocoder-backdrop\"></div>\r\n\r\n  </ng-container>\r\n\r\n\r\n</div>", styles: ["::-moz-placeholder{font-size:14px;color:#797979}::placeholder{font-size:14px;color:#797979}*:focus{outline:0}p,span,input,li{margin:0;font-size:14px;color:#444}.geocoder-container{position:relative;width:100%;height:100%;max-width:100%;overscroll-behavior-y:none}.geocoder-fullscreen-mode{position:fixed;top:0;right:0;left:0;height:100vh}.geocoder-search-container{position:relative;display:flex;align-items:center;width:100%;z-index:1;box-shadow:0 3px 6px #ffffff29,0 3px 6px #9d9d9d3b;background:#fff;box-sizing:border-box}.geocoder-search-input{flex:1 1 auto;padding:14px 15px;max-width:calc(100% - 80px);overflow:hidden;text-overflow:ellipsis;font-size:14px;border:none}.geocoder-fullscreen-mode .geocoder-search-input{padding-left:0}.geocoder-backdrop{position:fixed;top:0;right:0;bottom:0;left:0;height:100%;width:100%;z-index:0;background:#f5f5f5}button{padding:0 15px;cursor:pointer}.backButton{padding:12px 15px 9px;background:#fff;fill:#797979;border:none}.backButton svg{width:21px}.searchButton{position:absolute;right:0;padding:15px 15px 12px;background:#fff;border:none;pointer-events:none}.searchButton--resultshown{right:48px}.closeButton{position:absolute;right:0;padding:12px 15px 9px;background:#fff;border:none}.closeButton:before{content:\"\";position:absolute;top:8px;left:0;bottom:8px;width:1px;background-color:#eee}svg{width:18px;color:#797979}.backButton:hover svg,.searchButton:hover svg,.closeButton:hover svg,.highlight svg{fill:#008cba;color:#008cba;transition:all .1s cubic-bezier(.075,.82,.165,1)}.geocoder-suggestions-results{position:relative;width:100%;z-index:1;max-height:calc(100% - 49px);overflow-y:auto;overscroll-behavior-y:none;border-top:1px solid #f1f1f1;background:#fff;box-shadow:0 3px 6px #ffffff29,0 3px 6px #9d9d9d3b}.geocoder-suggestions-list{margin:0;padding:0;list-style-type:none}.geocoder-suggestion{display:flex;align-items:center;padding:12px 15px;border-bottom:1px solid #f1f1f1}.geocoder-suggestion:hover{cursor:pointer;background-color:#f7f7f7}.geocoder-suggestion-main{margin-right:10px}.geocoder-suggestion-title{font-size:14px}.geocoder-suggestion-subtitle{font-size:14px;color:#838383}.geocoder-suggestion-type{margin:0 0 0 auto;font-size:11px;font-weight:700;text-transform:uppercase;color:#bfbfbf}.geocoder-suggestion:hover,.geocoder-collation:hover{cursor:pointer;background-color:#f8f8f8}.focus-background{background-color:#f7f7f7}.geocoder-no-results{position:relative;width:100%;padding:18px 15px;font-size:14px;z-index:2;background:#fff;border-top:1px solid #f1f1f1;box-shadow:0 3px 6px #ffffff29,0 3px 6px #9d9d9d3b;box-sizing:border-box}.geocoder-collation{z-index:1}.geocoder-collation:hover{cursor:pointer;background-color:#f7f7f7}.geocoder-collations{position:relative;width:100%;z-index:2;background:#fff;border-top:1px solid #f1f1f1;box-shadow:0 3px 6px #ffffff29,0 3px 6px #9d9d9d3b}.geocoder-collations-list{margin:0;padding:0;list-style-type:none}.geocoder-collations-list li{padding:15px;font-size:14px;border-bottom:1px solid #f1f1f1}\n"], dependencies: [{ kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i2.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: i2.NgSwitchDefault, selector: "[ngSwitchDefault]" }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.MaxLengthValidator, selector: "[maxlength][formControlName],[maxlength][formControl],[maxlength][ngModel]", inputs: ["maxlength"] }, { kind: "directive", type: i3.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "pipe", type: i2.AsyncPipe, name: "async" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.6", ngImport: i0, type: GeocoderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'angular-geocoder', host: { 'class': 'geocoder' }, template: "<div *ngIf=\"places$ | async as places\" #geocoder (keydown.ArrowUp)=\"moveUp()\" (keydown.ArrowDown)=\"moveDown(places)\"\r\n  (keydown.Enter)=\"handleEnter(places)\" class=\"geocoder-container\"\r\n  [class.geocoder-fullscreen-mode]=\"hasFocus && fullscreen\">\r\n  <!-- Input -->\r\n  <div class=\"geocoder-search-container\">\r\n    <button class=\"backButton\" *ngIf=\"hasFocus === true && fullscreen === true\" (click)=\"clear()\">\r\n      <svg height=\"24px\" version=\"1.1\" viewBox=\"0 0 768 768\">\r\n        <g id=\"ignore\">\r\n        </g>\r\n        <path\r\n          d=\"M406.624 585.376l-169.376-169.376h370.752c17.664 0 32-14.336 32-32s-14.336-32-32-32h-370.752l169.376-169.376c12.512-12.512 12.512-32.768 0-45.248s-32.768-12.512-45.248 0l-224 224c-3.072 3.072-5.376 6.592-6.944 10.368-1.632 3.904-2.432 8.096-2.432 12.256 0 8.192 3.136 16.384 9.376 22.624l224 224c12.512 12.512 32.768 12.512 45.248 0s12.512-32.768 0-45.248z\">\r\n        </path>\r\n      </svg>\r\n    </button>\r\n    <input (focus)=\"showSuggestions()\" [formControl]=\"searchControl\" class=\"geocoder-search-input\"\r\n      [placeholder]=\"formattedPlaceholder\" type=\"text\" maxlength=\"100\">\r\n    <button class=\"searchButton\" [class.searchButton--resultshown]=\"lookupResponseFound === true\" [ngClass]=\"{'highlight': canQuery()}\">\r\n      <svg viewBox=\"0 0 512 512\">\r\n        <path fill=\"currentColor\"\r\n          d=\"M508.5 481.6l-129-129c-2.3-2.3-5.3-3.5-8.5-3.5h-10.3C395 312 416 262.5 416 208 416 93.1 322.9 0 208 0S0 93.1 0 208s93.1 208 208 208c54.5 0 104-21 141.1-55.2V371c0 3.2 1.3 6.2 3.5 8.5l129 129c4.7 4.7 12.3 4.7 17 0l9.9-9.9c4.7-4.7 4.7-12.3 0-17zM208 384c-97.3 0-176-78.7-176-176S110.7 32 208 32s176 78.7 176 176-78.7 176-176 176z\"\r\n          class=\"\"></path>\r\n      </svg>\r\n    </button>\r\n    <button *ngIf=\"lookupResponseFound === true\" class=\"closeButton\" (click)=\"clear()\"\r\n      [ngClass]=\"{'highlight': canClear()}\"> \r\n      <svg viewBox=\"0 0 384 512\">\r\n        <path fill=\"currentColor\"\r\n          d=\"M217.5 256l137.2-137.2c4.7-4.7 4.7-12.3 0-17l-8.5-8.5c-4.7-4.7-12.3-4.7-17 0L192 230.5 54.8 93.4c-4.7-4.7-12.3-4.7-17 0l-8.5 8.5c-4.7 4.7-4.7 12.3 0 17L166.5 256 29.4 393.2c-4.7 4.7-4.7 12.3 0 17l8.5 8.5c4.7 4.7 12.3 4.7 17 0L192 281.5l137.2 137.2c4.7 4.7 12.3 4.7 17 0l8.5-8.5c4.7-4.7 4.7-12.3 0-17L217.5 256z\"\r\n          class=\"\"></path>\r\n      </svg>\r\n    </button>\r\n  </div>\r\n\r\n  <ng-container *ngIf=\"hasFocus === true\">\r\n    <!-- Search results-->\r\n    <div class=\"geocoder-suggestions-results\" *ngIf=\"places.length > 0\">\r\n      <ul class=\"geocoder-suggestions-list\">\r\n        <li class=\"geocoder-suggestion\" tabindex={{i}} *ngFor=\"let place of places; let i = index;\"\r\n          (click)=\"lookup(place.id)\" [ngClass]=\"{'focus-background': isHighlighted(i)}\">\r\n\r\n          <ng-container [ngSwitch]=\"place.type\">\r\n\r\n            <!-- Adres -->\r\n            <ng-container *ngSwitchCase=\"'adres'\">\r\n              <div class=\"geocoder-suggestion-main\">\r\n                <div class=\"geocoder-suggestion-title\">\r\n                  {{place.straatnaam }} {{place.huis_nlt}}\r\n                </div>\r\n                <div class=\"geocoder-suggestion-subtitle\"> {{place.woonplaatsnaam}}</div>\r\n              </div>\r\n            </ng-container>\r\n\r\n            <!-- Perceel -->\r\n            <ng-container *ngSwitchCase=\"'perceel'\">\r\n              <div class=\"geocoder-suggestion-main\">\r\n                <div class=\"geocoder-suggestion-title\">\r\n                  Perceel {{place.kadastrale_gemeentecode }} {{place.kadastrale_sectie}} {{place.perceelnummer}}\r\n                </div>\r\n                <div class=\"geocoder-suggestion-subtitle\"> {{place.kadastrale_gemeentenaam}}</div>\r\n              </div>\r\n            </ng-container>\r\n\r\n            <!-- Weg -->\r\n            <ng-container *ngSwitchCase=\"'weg'\">\r\n              <div class=\"geocoder-suggestion-main\">\r\n                <div class=\"geocoder-suggestion-title\">\r\n                  {{place.straatnaam }}\r\n                </div>\r\n                <div class=\"geocoder-suggestion-subtitle\"> {{place.woonplaatsnaam}}</div>\r\n              </div>\r\n            </ng-container>\r\n\r\n            <!-- Anything other than addres, parcel en weg -->\r\n            <ng-container *ngSwitchDefault>\r\n              <div class=\"geocoder-suggestion-main\">\r\n                <p class=\"geocoder-suggestion-title\"\r\n                  [innerHTML]=\"place.highlight\">\r\n                </p>\r\n              </div>\r\n            </ng-container>\r\n\r\n          </ng-container>\r\n\r\n          <p class=\"geocoder-suggestion-type\"> {{place.type}} </p>\r\n\r\n        </li>\r\n      </ul>\r\n    </div>\r\n\r\n    <div class=\"geocoder-no-results\" *ngIf=\"(isNoResultsFound$ | async) === true\">\r\n      <p>Geen zoekresultaten voor <strong>\"{{searchControl.value}}\"</strong></p>\r\n    </div>\r\n\r\n    <ng-container *ngIf=\"collations$ | async as collations\">\r\n      <ng-container *ngIf=\"noResult$ | async as noResult\">\r\n        <div class=\"geocoder-collations\" *ngIf=\"collations.length > 0 && places.length === 0 && noResult\">\r\n          <ul class=\"geocoder-collations-list\">\r\n            <li class=\"geocoder-collation\" tabindex={{i}} (click)=\"onCollationClick(collation.naam)\"\r\n              *ngFor=\"let collation of collations; let i = index;\" [innerHTML]=\"collation.weergavenaam\">\r\n            </li>\r\n          </ul>\r\n        </div>\r\n      </ng-container>\r\n    </ng-container>\r\n\r\n    <!-- Backdrop-->\r\n    <div *ngIf=\"fullscreen === true\" class=\"geocoder-backdrop\"></div>\r\n\r\n  </ng-container>\r\n\r\n\r\n</div>", styles: ["::-moz-placeholder{font-size:14px;color:#797979}::placeholder{font-size:14px;color:#797979}*:focus{outline:0}p,span,input,li{margin:0;font-size:14px;color:#444}.geocoder-container{position:relative;width:100%;height:100%;max-width:100%;overscroll-behavior-y:none}.geocoder-fullscreen-mode{position:fixed;top:0;right:0;left:0;height:100vh}.geocoder-search-container{position:relative;display:flex;align-items:center;width:100%;z-index:1;box-shadow:0 3px 6px #ffffff29,0 3px 6px #9d9d9d3b;background:#fff;box-sizing:border-box}.geocoder-search-input{flex:1 1 auto;padding:14px 15px;max-width:calc(100% - 80px);overflow:hidden;text-overflow:ellipsis;font-size:14px;border:none}.geocoder-fullscreen-mode .geocoder-search-input{padding-left:0}.geocoder-backdrop{position:fixed;top:0;right:0;bottom:0;left:0;height:100%;width:100%;z-index:0;background:#f5f5f5}button{padding:0 15px;cursor:pointer}.backButton{padding:12px 15px 9px;background:#fff;fill:#797979;border:none}.backButton svg{width:21px}.searchButton{position:absolute;right:0;padding:15px 15px 12px;background:#fff;border:none;pointer-events:none}.searchButton--resultshown{right:48px}.closeButton{position:absolute;right:0;padding:12px 15px 9px;background:#fff;border:none}.closeButton:before{content:\"\";position:absolute;top:8px;left:0;bottom:8px;width:1px;background-color:#eee}svg{width:18px;color:#797979}.backButton:hover svg,.searchButton:hover svg,.closeButton:hover svg,.highlight svg{fill:#008cba;color:#008cba;transition:all .1s cubic-bezier(.075,.82,.165,1)}.geocoder-suggestions-results{position:relative;width:100%;z-index:1;max-height:calc(100% - 49px);overflow-y:auto;overscroll-behavior-y:none;border-top:1px solid #f1f1f1;background:#fff;box-shadow:0 3px 6px #ffffff29,0 3px 6px #9d9d9d3b}.geocoder-suggestions-list{margin:0;padding:0;list-style-type:none}.geocoder-suggestion{display:flex;align-items:center;padding:12px 15px;border-bottom:1px solid #f1f1f1}.geocoder-suggestion:hover{cursor:pointer;background-color:#f7f7f7}.geocoder-suggestion-main{margin-right:10px}.geocoder-suggestion-title{font-size:14px}.geocoder-suggestion-subtitle{font-size:14px;color:#838383}.geocoder-suggestion-type{margin:0 0 0 auto;font-size:11px;font-weight:700;text-transform:uppercase;color:#bfbfbf}.geocoder-suggestion:hover,.geocoder-collation:hover{cursor:pointer;background-color:#f8f8f8}.focus-background{background-color:#f7f7f7}.geocoder-no-results{position:relative;width:100%;padding:18px 15px;font-size:14px;z-index:2;background:#fff;border-top:1px solid #f1f1f1;box-shadow:0 3px 6px #ffffff29,0 3px 6px #9d9d9d3b;box-sizing:border-box}.geocoder-collation{z-index:1}.geocoder-collation:hover{cursor:pointer;background-color:#f7f7f7}.geocoder-collations{position:relative;width:100%;z-index:2;background:#fff;border-top:1px solid #f1f1f1;box-shadow:0 3px 6px #ffffff29,0 3px 6px #9d9d9d3b}.geocoder-collations-list{margin:0;padding:0;list-style-type:none}.geocoder-collations-list li{padding:15px;font-size:14px;border-bottom:1px solid #f1f1f1}\n"] }]
        }], ctorParameters: function () { return [{ type: GeocoderService }]; }, propDecorators: { geocoderRef: [{
                type: ViewChild,
                args: ['geocoder', { static: false }]
            }], type: [{
                type: Input
            }], searchInput: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], resultCountLimit: [{
                type: Input
            }], province: [{
                type: Input
            }], fullscreen: [{
                type: Input
            }], placeFound: [{
                type: Output
            }], clearResults: [{
                type: Output
            }], query: [{
                type: Output
            }], hasFocus: [{
                type: HostBinding,
                args: ['class.geocoder--selected']
            }], clickout: [{
                type: HostListener,
                args: ['document:click', ['$event']]
            }] } });

class GeocoderModule {
}
GeocoderModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.6", ngImport: i0, type: GeocoderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
GeocoderModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.0.6", ngImport: i0, type: GeocoderModule, declarations: [GeocoderComponent], imports: [HttpClientModule,
        CommonModule,
        ReactiveFormsModule], exports: [GeocoderComponent] });
GeocoderModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.0.6", ngImport: i0, type: GeocoderModule, providers: [GeocoderService], imports: [HttpClientModule,
        CommonModule,
        ReactiveFormsModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.6", ngImport: i0, type: GeocoderModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        HttpClientModule,
                        CommonModule,
                        ReactiveFormsModule
                    ],
                    declarations: [GeocoderComponent],
                    exports: [GeocoderComponent],
                    providers: [GeocoderService]
                }]
        }] });

/*
 * Public API Surface of angular-geocoder
 */

/**
 * Generated bundle index. Do not edit.
 */

export { GeocoderComponent, GeocoderModule, GeocoderService };
//# sourceMappingURL=angular-geocoder.mjs.map
